@@ -16,10 +16,10 @@ from .utils.collections import AttributeDict
 from .utils.time import (ffwd, humanize_seconds, localize, maybe_make_aware,
                          maybe_timedelta, remaining, timezone, weekday)
 
-__all__ = [
+__all__ = (
     'ParseException', 'schedule', 'crontab', 'crontab_parser',
     'maybe_schedule', 'solar',
-]
+)
 
 schedstate = namedtuple('schedstate', ('is_due', 'next'))
 
@@ -113,8 +113,8 @@ class schedule(BaseSchedule):
         relative (bool):  If set to True the run time will be rounded to the
             resolution of the interval.
         nowfun (Callable): Function returning the current date and time
-            (class:`~datetime.datetime`).
-        app (~@Celery): Celery app instance.
+            (:class:`~datetime.datetime`).
+        app (Celery): Celery app instance.
     """
 
     relative = False
@@ -689,7 +689,7 @@ class solar(BaseSchedule):
         lon (int): The longitude of the observer.
         nowfun (Callable): Function returning the current date and time
             as a class:`~datetime.datetime`.
-        app (~@Celery): Celery app instance.
+        app (Celery): Celery app instance.
     """
 
     _all_events = {
@@ -730,7 +730,7 @@ class solar(BaseSchedule):
         'dawn_nautical': True,
         'dawn_civil': True,
         'sunrise': False,
-        'solar_noon': True,
+        'solar_noon': False,
         'sunset': False,
         'dusk_civil': True,
         'dusk_nautical': True,
@@ -785,10 +785,16 @@ class solar(BaseSchedule):
         last_run_at_utc = localize(last_run_at, timezone.utc)
         self.cal.date = last_run_at_utc
         try:
-            next_utc = getattr(self.cal, self.method)(
-                self.ephem.Sun(),
-                start=last_run_at_utc, use_center=self.use_center,
-            )
+            if self.use_center:
+                next_utc = getattr(self.cal, self.method)(
+                    self.ephem.Sun(),
+                    start=last_run_at_utc, use_center=self.use_center
+                )
+            else:
+                next_utc = getattr(self.cal, self.method)(
+                    self.ephem.Sun(), start=last_run_at_utc
+                )
+
         except self.ephem.CircumpolarError:  # pragma: no cover
             # Sun won't rise/set today.  Check again tomorrow
             # (specifically, after the next anti-transit).
